##  Using Shape Variants
If multiple shapes are assigned to a fact sheet type in a template, you can select from the available variants in the diagram editor.
To select a shape variant, do the following:
  1. Open a diagram in edit mode.
  2. Choose the fact sheet in the editor.
  3. Select the desired variant from the Variant dropdown in the right panel.![An animated image showing how to apply shape variants.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiodefe61ec61454888be0f955004ddf8ed_LowRes.gif)
